@@ -29,6 +29,7 @@
 
 from mingus.core import meter as _meter
 from NoteContainers import NoteContainer
+from Note import Note
 
 class Bar:
 
@@ -66,13 +67,22 @@ class Bar:
 
 
 	def place_notes(self, notes, duration):
-		"""Places the NoteContainer notes on the current_beat."""
+		"""Places the NoteContainer notes on the current_beat.
+		Notes can be strings, Notes, list of strings, list of Notes or
+		NoteContainers."""
 
 		# note should be able to be strings, lists, Notes or NoteContainers
+		if hasattr(notes, "notes"):
+			pass
+		elif hasattr(notes, "name"):
+			notes = NoteContainer(notes)
+		elif type(notes) == str:
+			notes = NoteContainer(notes)
+		elif type(notes) == list:
+			notes = NoteContainer(notes)
 
 		if _meter.valid_beat_duration(duration):
-			if self.current_beat + 1.0 / duration <= self.length or\
-							self.length == 0.0:
+			if self.current_beat + 1.0 / duration <= self.length or self.length == 0.0:
 				self.bar.append([self.current_beat, duration, notes])
 				self.current_beat += 1.0 / duration
 				return True
@@ -131,7 +141,10 @@ class Bar:
 
 	def __add__(self, note_container):
 		"""Enables the '+' operator on Bars"""
-		self.place_notes(note_container, self.meter[1])
+		if self.meter[1] != 0:
+			return self.place_notes(note_container, self.meter[1])
+		else:
+			return self.place_notes(note_container, 4)
 
 	def __getitem__(self, index):
 		"""Allows you to use [index] notation on Bars to get the 
@@ -142,8 +155,18 @@ class Bar:
 		"""Allows you to use [] = notation on Bars. The value
 		should be NoteContainer, or a string/list/Note understood
 		by the NoteContainer."""
-		if value == str:
+
+		if hasattr(value, "notes"):
+			pass
+		elif hasattr(value, "name"):
 			value = NoteContainer(value)
+		elif type(value) == str:
+			value = NoteContainer(value)
+		elif type(value) == list:
+			res = NoteContainer()
+			for x in value:
+				res + x
+			value = res
 		self.bar[index][2] = value
 
 	def __repr__(self):
@@ -151,3 +174,9 @@ class Bar:
 
 	def __len__(self):
 		return len(self.bar)
+
+	def __eq__(self, other):
+		for b in range(0, len(self.bar) - 1):
+			if self.bar[b] != other.bar[b]:
+				return False
+		return True
