@@ -30,7 +30,7 @@ class Track:
 	bars = []
 	instrument = None
 
-	def __init__(self, instrument):
+	def __init__(self, instrument = None):
 		self.bars = []
 		self.instrument = instrument
 
@@ -42,7 +42,7 @@ class Track:
 
 
 	def add_note(self, note):
-		if self.instrument.can_play_notes(note):
+		if not(self.instrument.can_play_notes(note)):
 			# raise exception
 			return False
 		last_bar = self.bars[-1]
